==> estateplat-common-1.2.4-20210915.025716-873-sources.jar: cn/gtmap/estateplat/model/server/core/BdcFdcqDz.java <==
package cn.gtmap.estateplat.model.server.core;

import cn.gtmap.estateplat.core.annotation.Zd;

import javax.persistence.Table;
import javax.persistence.Transient;
import java.util.Date;
import java.util.List;

/**
 * 房地产权登记信息（项目内多幢房屋）
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_fdcq_dz")
public class BdcFdcqDz extends QllxParent implements InsertVo,QllxVo{
    @Transient
    List<BdcFwfzxx> fwfzxxList;
    /* @Id*/
    //  private String qlid;//权利Id
    //  private String bdcdyid;//不动产单元Id
    private String fwsyqr;//房屋所有权人
    private String tdsyqr;//土地使用人
    private Date tdsyksqx;//土地使用开始期限
    private Date tdsyjsqx;//土地使用结束期限
    private Double dytdmj;//独用土地面积(m2)
    private Double fttdmj;//分摊土地面积(m2)
    private Double fdcjyjg;//房地产交易价格(万元)
    private String ywh;//业务号
    private String qllx;//权利类型
    /* private String proid;//项目ID*/
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记

    private Integer qszt;//权属状态
    private String zrzh;//自然幢号

    @Zd(table = "bdc_zd_fwxz")
    private String fwxz;//房屋性质
    private String fwdah;//房屋档案号
    private String cqly;//产权来源
    private String lsyd;//隶属用地
    private Double ftjzmj;//分摊建筑面积

    private Double tnjzmj;//专有/套内建筑面积(m2)

    private Integer fwlx;//房屋类型

    private Date jgsj;//竣工时间

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/6/25
     * @description 土地使用权面积，记录既有独用又有分摊的情况，是独用土地面积和分摊土地面积之和，单位为平方米
     */
    private Double tdsyqmj;

    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号
    private Integer jznd;//建筑年度

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 房地产交易合同号
     */
    private String fdcjyhth;

    private Double htje;//合同金额

    private Date htqdsj;//合同签订时间

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_fdcq_dz表增加冗余字段qlrzjzl、qlrzjh、ywr、ywrzjzl、ywrzjh、bdcdyh、bdcqzh、zl
     */
    private String qlrzjzl; //权利人证件种类

    private String qlrzjh; //权利人证件号

    private String ywr;  //义务人

    private String ywrzjzl; //义务人证件种类

    private String ywrzjh; //义务人证件号

    private String bdcdyh; //不动产单元号

    private String bdcqzh; //不动产权证号

    private String zl; //坐落

    private String bz;//备注
//    土地使用开始期限2
    private Date tdsyksqx2;
//    土地使用结束期限2
    private Date tdsyjsqx2;
//    土地使用开始期限3
    private Date tdsyksqx3;
//    土地使用结束期限3
    private Date tdsyjsqx3;
    private String qlqtzk; //权利其他状况
    private Double czmj; //超占面积
    private Integer tdycsynx; //土地有偿使用年限
    private String sfcz; //是否超占
    private String fcqdh; //房产丘地号
    private String sfjckh;//是否继承空户 0不继承，1继承
    private Integer xzzrnx;//限制转让年限
    private Date xzzrdbsj;//限制转让登簿时间
    private Integer cxzt;//撤销状态 1：已撤销,0或空：未撤销

    private String jcnd;//建成年代

    private Double qqtdmj;//确权土地面积

    private Double qqjzmj;//确权建筑面积

    private String jedw;//金额单位 字典表BDC_ZD_JEDW

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }
    public Integer getCxzt() {
        return cxzt;
    }

    public void setCxzt(Integer cxzt) {
        this.cxzt = cxzt;
    }
    public String getBz() { return bz; }

    public void setBz(String bz) { this.bz = bz; }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getQlrzjzl() {
        return qlrzjzl;
    }

    public void setQlrzjzl(String qlrzjzl) {
        this.qlrzjzl = qlrzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getYwr() {
        return ywr;
    }

    public void setYwr(String ywr) {
        this.ywr = ywr;
    }

    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }


    public java.lang.String getQlid() {
        return qlid;
    }

    public void setQlid(java.lang.String qlid) {
        this.qlid = qlid;
    }

    public java.lang.String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(java.lang.String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public java.lang.String getYwh() {
        return ywh;
    }

    public void setYwh(java.lang.String ywh) {
        this.ywh = ywh;
    }


    public java.lang.Integer getQszt() {
        return qszt;
    }

    public void setQszt(java.lang.Integer qszt) {
        this.qszt = qszt;
    }


    public Date getJgsj() {
        return jgsj;
    }

    public void setJgsj(Date jgsj) {
        this.jgsj = jgsj;
    }


    public List<BdcFwfzxx> getFwfzxxList() {
        return fwfzxxList;
    }

    public void setFwfzxxList(List<BdcFwfzxx> fwfzxxList) {
        this.fwfzxxList = fwfzxxList;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public String getFwsyqr() {
        return fwsyqr;
    }

    public void setFwsyqr(String fwsyqr) {
        this.fwsyqr = fwsyqr;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public Date getTdsyksqx() {
        return tdsyksqx;
    }

    public void setTdsyksqx(Date tdsyksqx) {
        this.tdsyksqx = tdsyksqx;
    }

    public Date getTdsyjsqx() {
        return tdsyjsqx;
    }

    public void setTdsyjsqx(Date tdsyjsqx) {
        this.tdsyjsqx = tdsyjsqx;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getFdcjyjg() {
        return fdcjyjg;
    }

    public void setFdcjyjg(Double fdcjyjg) {
        this.fdcjyjg = fdcjyjg;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getCqly() {
        return cqly;
    }

    public void setCqly(String cqly) {
        this.cqly = cqly;
    }

    public String getFwdah() {
        return fwdah;
    }

    public void setFwdah(String fwdah) {
        this.fwdah = fwdah;
    }

    public String getLsyd() {
        return lsyd;
    }

    public void setLsyd(String lsyd) {
        this.lsyd = lsyd;
    }

    public Double getFtjzmj() {
        return ftjzmj;
    }

    public void setFtjzmj(Double ftjzmj) {
        this.ftjzmj = ftjzmj;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public Integer getFwlx() {
        return fwlx;
    }

    public void setFwlx(Integer fwlx) {
        this.fwlx = fwlx;
    }

    public Double getTdsyqmj() {
        return tdsyqmj;
    }

    public void setTdsyqmj(Double tdsyqmj) {
        this.tdsyqmj = tdsyqmj;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public Integer getJznd() {
        return jznd;
    }

    public void setJznd(Integer jznd) {
        this.jznd = jznd;
    }

    public String getFdcjyhth() {
        return fdcjyhth;
    }

    public void setFdcjyhth(String fdcjyhth) {
        this.fdcjyhth = fdcjyhth;
    }

    public Double getHtje() {
        return htje;
    }

    public void setHtje(Double htje) {
        this.htje = htje;
    }

    public Date getHtqdsj() {
        return htqdsj;
    }

    public void setHtqdsj(Date htqdsj) {
        this.htqdsj = htqdsj;
    }

    public Date getTdsyksqx2() {
        return tdsyksqx2;
    }

    public void setTdsyksqx2(Date tdsyksqx2) {
        this.tdsyksqx2 = tdsyksqx2;
    }

    public Date getTdsyjsqx2() {
        return tdsyjsqx2;
    }

    public void setTdsyjsqx2(Date tdsyjsqx2) {
        this.tdsyjsqx2 = tdsyjsqx2;
    }

    public Date getTdsyksqx3() {
        return tdsyksqx3;
    }

    public void setTdsyksqx3(Date tdsyksqx3) {
        this.tdsyksqx3 = tdsyksqx3;
    }

    public Date getTdsyjsqx3() {
        return tdsyjsqx3;
    }

    public void setTdsyjsqx3(Date tdsyjsqx3) {
        this.tdsyjsqx3 = tdsyjsqx3;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    public Double getCzmj() {
        return czmj;
    }

    public void setCzmj(Double czmj) {
        this.czmj = czmj;
    }

    public Integer getTdycsynx() {
        return tdycsynx;
    }

    public void setTdycsynx(Integer tdycsynx) {
        this.tdycsynx = tdycsynx;
    }

    public String getSfcz() {
        return sfcz;
    }

    public void setSfcz(String sfcz) {
        this.sfcz = sfcz;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public String getFcqdh() {
        return fcqdh;
    }

    public void setFcqdh(String fcqdh) {
        this.fcqdh = fcqdh;
    }

    public String getSfjckh() {
        return sfjckh;
    }

    public void setSfjckh(String sfjckh) {
        this.sfjckh = sfjckh;
    }

    public Integer getXzzrnx() {
        return xzzrnx;
    }

    public void setXzzrnx(Integer xzzrnx) {
        this.xzzrnx = xzzrnx;
    }

    public Date getXzzrdbsj() {
        return xzzrdbsj;
    }

    public void setXzzrdbsj(Date xzzrdbsj) {
        this.xzzrdbsj = xzzrdbsj;
    }

    public String getJcnd() {
        return jcnd;
    }

    public void setJcnd(String jcnd) {
        this.jcnd = jcnd;
    }

    public Double getQqtdmj() {
        return qqtdmj;
    }

    public void setQqtdmj(Double qqtdmj) {
        this.qqtdmj = qqtdmj;
    }

    public Double getQqjzmj() {
        return qqjzmj;
    }

    public void setQqjzmj(Double qqjzmj) {
        this.qqjzmj = qqjzmj;
    }
}

==> estateplat-common-1.2.4-20220315.013728-984-sources.jar: cn/gtmap/estateplat/model/server/core/BdcFdcqDz.java <==
package cn.gtmap.estateplat.model.server.core;

import cn.gtmap.estateplat.core.annotation.Zd;

import javax.persistence.Table;
import javax.persistence.Transient;
import java.util.Date;
import java.util.List;

/**
 * 房地产权登记信息（项目内多幢房屋）
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_fdcq_dz")
public class BdcFdcqDz extends QllxParent implements InsertVo, QllxVo {
    @Transient
    List<BdcFwfzxx> fwfzxxList;
    /* @Id*/
    //  private String qlid;//权利Id
    //  private String bdcdyid;//不动产单元Id
    private String fwsyqr;//房屋所有权人
    private String tdsyqr;//土地使用人
    private Date tdsyksqx;//土地使用开始期限
    private Date tdsyjsqx;//土地使用结束期限
    private Double dytdmj;//独用土地面积(m2)
    private Double fttdmj;//分摊土地面积(m2)
    private Double fdcjyjg;//房地产交易价格(万元)
    private String ywh;//业务号
    private String qllx;//权利类型
    /* private String proid;//项目ID*/
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记

    private Integer qszt;//权属状态
    private String zrzh;//自然幢号

    @Zd(table = "bdc_zd_fwxz")
    private String fwxz;//房屋性质
    private String fwdah;//房屋档案号
    private String cqly;//产权来源
    private String lsyd;//隶属用地
    private Double ftjzmj;//分摊建筑面积

    private Double tnjzmj;//专有/套内建筑面积(m2)

    private Integer fwlx;//房屋类型

    private Date jgsj;//竣工时间

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/6/25
     * @description 土地使用权面积，记录既有独用又有分摊的情况，是独用土地面积和分摊土地面积之和，单位为平方米
     */
    private Double tdsyqmj;

    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号
    private Integer jznd;//建筑年度

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 房地产交易合同号
     */
    private String fdcjyhth;

    private Double htje;//合同金额

    private Date htqdsj;//合同签订时间

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_fdcq_dz表增加冗余字段qlrzjzl、qlrzjh、ywr、ywrzjzl、ywrzjh、bdcdyh、bdcqzh、zl
     */
    private String qlrzjzl; //权利人证件种类

    private String qlrzjh; //权利人证件号

    private String ywr;  //义务人

    private String ywrzjzl; //义务人证件种类

    private String ywrzjh; //义务人证件号

    private String bdcdyh; //不动产单元号

    private String bdcqzh; //不动产权证号

    private String zl; //坐落

    private String bz;//备注
    //    土地使用开始期限2
    private Date tdsyksqx2;
    //    土地使用结束期限2
    private Date tdsyjsqx2;
    //    土地使用开始期限3
    private Date tdsyksqx3;
    //    土地使用结束期限3
    private Date tdsyjsqx3;
    //    土地使用开始期限4
    private Date tdsyksqx4;
    //    土地使用结束期限4
    private Date tdsyjsqx4;
    //    土地使用开始期限5
    private Date tdsyksqx5;
    //    土地使用结束期限5
    private Date tdsyjsqx5;
    private String qlqtzk; //权利其他状况
    private Double czmj; //超占面积
    private Integer tdycsynx; //土地有偿使用年限
    private String sfcz; //是否超占
    private String fcqdh; //房产丘地号
    private String sfjckh;//是否继承空户 0不继承，1继承
    private Integer xzzrnx;//限制转让年限
    private Date xzzrdbsj;//限制转让登簿时间
    private Integer cxzt;//撤销状态 1：已撤销,0或空：未撤销

    private String jcnd;//建成年代

    private Double qqtdmj;//确权土地面积

    private Double qqjzmj;//确权建筑面积

    private String jedw;//金额单位 字典表BDC_ZD_JEDW

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }

    public Integer getCxzt() {
        return cxzt;
    }

    public void setCxzt(Integer cxzt) {
        this.cxzt = cxzt;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getQlrzjzl() {
        return qlrzjzl;
    }

    public void setQlrzjzl(String qlrzjzl) {
        this.qlrzjzl = qlrzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getYwr() {
        return ywr;
    }

    public void setYwr(String ywr) {
        this.ywr = ywr;
    }

    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }


    public java.lang.String getQlid() {
        return qlid;
    }

    public void setQlid(java.lang.String qlid) {
        this.qlid = qlid;
    }

    public java.lang.String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(java.lang.String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public java.lang.String getYwh() {
        return ywh;
    }

    public void setYwh(java.lang.String ywh) {
        this.ywh = ywh;
    }


    public java.lang.Integer getQszt() {
        return qszt;
    }

    public void setQszt(java.lang.Integer qszt) {
        this.qszt = qszt;
    }


    public Date getJgsj() {
        return jgsj;
    }

    public void setJgsj(Date jgsj) {
        this.jgsj = jgsj;
    }


    public List<BdcFwfzxx> getFwfzxxList() {
        return fwfzxxList;
    }

    public void setFwfzxxList(List<BdcFwfzxx> fwfzxxList) {
        this.fwfzxxList = fwfzxxList;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public String getFwsyqr() {
        return fwsyqr;
    }

    public void setFwsyqr(String fwsyqr) {
        this.fwsyqr = fwsyqr;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public Date getTdsyksqx() {
        return tdsyksqx;
    }

    public void setTdsyksqx(Date tdsyksqx) {
        this.tdsyksqx = tdsyksqx;
    }

    public Date getTdsyjsqx() {
        return tdsyjsqx;
    }

    public void setTdsyjsqx(Date tdsyjsqx) {
        this.tdsyjsqx = tdsyjsqx;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getFdcjyjg() {
        return fdcjyjg;
    }

    public void setFdcjyjg(Double fdcjyjg) {
        this.fdcjyjg = fdcjyjg;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getCqly() {
        return cqly;
    }

    public void setCqly(String cqly) {
        this.cqly = cqly;
    }

    public String getFwdah() {
        return fwdah;
    }

    public void setFwdah(String fwdah) {
        this.fwdah = fwdah;
    }

    public String getLsyd() {
        return lsyd;
    }

    public void setLsyd(String lsyd) {
        this.lsyd = lsyd;
    }

    public Double getFtjzmj() {
        return ftjzmj;
    }

    public void setFtjzmj(Double ftjzmj) {
        this.ftjzmj = ftjzmj;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public Integer getFwlx() {
        return fwlx;
    }

    public void setFwlx(Integer fwlx) {
        this.fwlx = fwlx;
    }

    public Double getTdsyqmj() {
        return tdsyqmj;
    }

    public void setTdsyqmj(Double tdsyqmj) {
        this.tdsyqmj = tdsyqmj;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public Integer getJznd() {
        return jznd;
    }

    public void setJznd(Integer jznd) {
        this.jznd = jznd;
    }

    public String getFdcjyhth() {
        return fdcjyhth;
    }

    public void setFdcjyhth(String fdcjyhth) {
        this.fdcjyhth = fdcjyhth;
    }

    public Double getHtje() {
        return htje;
    }

    public void setHtje(Double htje) {
        this.htje = htje;
    }

    public Date getHtqdsj() {
        return htqdsj;
    }

    public void setHtqdsj(Date htqdsj) {
        this.htqdsj = htqdsj;
    }

    public Date getTdsyksqx2() {
        return tdsyksqx2;
    }

    public void setTdsyksqx2(Date tdsyksqx2) {
        this.tdsyksqx2 = tdsyksqx2;
    }

    public Date getTdsyjsqx2() {
        return tdsyjsqx2;
    }

    public void setTdsyjsqx2(Date tdsyjsqx2) {
        this.tdsyjsqx2 = tdsyjsqx2;
    }

    public Date getTdsyksqx3() {
        return tdsyksqx3;
    }

    public void setTdsyksqx3(Date tdsyksqx3) {
        this.tdsyksqx3 = tdsyksqx3;
    }

    public Date getTdsyjsqx3() {
        return tdsyjsqx3;
    }

    public void setTdsyjsqx3(Date tdsyjsqx3) {
        this.tdsyjsqx3 = tdsyjsqx3;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    public Double getCzmj() {
        return czmj;
    }

    public void setCzmj(Double czmj) {
        this.czmj = czmj;
    }

    public Integer getTdycsynx() {
        return tdycsynx;
    }

    public void setTdycsynx(Integer tdycsynx) {
        this.tdycsynx = tdycsynx;
    }

    public String getSfcz() {
        return sfcz;
    }

    public void setSfcz(String sfcz) {
        this.sfcz = sfcz;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public String getFcqdh() {
        return fcqdh;
    }

    public void setFcqdh(String fcqdh) {
        this.fcqdh = fcqdh;
    }

    public String getSfjckh() {
        return sfjckh;
    }

    public void setSfjckh(String sfjckh) {
        this.sfjckh = sfjckh;
    }

    public Integer getXzzrnx() {
        return xzzrnx;
    }

    public void setXzzrnx(Integer xzzrnx) {
        this.xzzrnx = xzzrnx;
    }

    public Date getXzzrdbsj() {
        return xzzrdbsj;
    }

    public void setXzzrdbsj(Date xzzrdbsj) {
        this.xzzrdbsj = xzzrdbsj;
    }

    public String getJcnd() {
        return jcnd;
    }

    public void setJcnd(String jcnd) {
        this.jcnd = jcnd;
    }

    public Double getQqtdmj() {
        return qqtdmj;
    }

    public void setQqtdmj(Double qqtdmj) {
        this.qqtdmj = qqtdmj;
    }

    public Double getQqjzmj() {
        return qqjzmj;
    }

    public void setQqjzmj(Double qqjzmj) {
        this.qqjzmj = qqjzmj;
    }

    public Date getTdsyksqx4() {
        return tdsyksqx4;
    }

    public void setTdsyksqx4(Date tdsyksqx4) {
        this.tdsyksqx4 = tdsyksqx4;
    }

    public Date getTdsyjsqx4() {
        return tdsyjsqx4;
    }

    public void setTdsyjsqx4(Date tdsyjsqx4) {
        this.tdsyjsqx4 = tdsyjsqx4;
    }

    public Date getTdsyksqx5() {
        return tdsyksqx5;
    }

    public void setTdsyksqx5(Date tdsyksqx5) {
        this.tdsyksqx5 = tdsyksqx5;
    }

    public Date getTdsyjsqx5() {
        return tdsyjsqx5;
    }

    public void setTdsyjsqx5(Date tdsyjsqx5) {
        this.tdsyjsqx5 = tdsyjsqx5;
    }
}
